# symautomata
Automata classes

A python framework for working with Automata. The framework contains a python implementation and C bindings using pywrapfst (optional).
This framework is part of the [lightbulb-framework](https://github.com/lightbulb-framework/lightbulb-framework).

## Changelog

0.0.12: Added support for latest Flex version in flex2fst file.  

## Contributors

* George Argyros
* Ioannis Stais
* Suman Jana
* Angelos D. Keromytis
* Aggelos Kiayias

## References

* *G. Argyros, I. Stais, S. Jana, A. D. Keromytis, and A. Kiayias. 2016. SFADiff: Automated Evasion Attacks and Fingerprinting Using Black-box Differential Automata Learning. In Proceedings of the 2016 ACM SIGSAC Conference on Computer and Communications Security (CCS '16). ACM, New York, NY, USA, 1690-1701. doi: 10.1145/2976749.2978383*
* *G. Argyros, I. Stais, A. Kiayias and A. D. Keromytis, "Back in Black: Towards Formal, Black Box Analysis of Sanitizers and Filters," 2016 IEEE Symposium on Security and Privacy (SP), San Jose, CA, 2016, pp. 91-109. doi: 10.1109/SP.2016.14*

## Acknowledgements

This research was partly supported by ERC project CODAMODA, #259152.

## License

MIT License as described in LICENSE file